# Type components in `ngComponentRouter`

Name | Description
--- | ---
Router | A `Router` is responsible for mapping URLs to components.
ChildRouter | This type extends the `Router`.
RootRouter | This type extends the `Router`.
ComponentInstruction | A `ComponentInstruction` represents the route state for a single component. An `Instruction` is composed of a tree of these `ComponentInstruction`s.
RouteDefinition | Each item in the RouteConfig for a Routing Component is an instance of this type. It can have the following properties:
RouteParams | A map of parameters for a given route, passed as part of the `ComponentInstruction` to the Lifecycle Hooks, such as `$routerOnActivate` and `$routerOnDeactivate`.